@@ -685,7 +685,7 @@ impl<'a, E: Endianness, K: BitRead<'a, E> + Eq + Hash, T: BitRead<'a, E>> BitRea
     }
 }
 
-#[derive(Clone, Debug)]
+#[derive(Clone, Debug, PartialEq)]
 /// Struct that lazily reads it's contents from the stream
 pub struct LazyBitRead<'a, T: BitRead<'a, E>, E: Endianness> {
     source: BitReadStream<'a, E>,
@@ -695,8 +695,8 @@ pub struct LazyBitRead<'a, T: BitRead<'a, E>, E: Endianness> {
 impl<'a, T: BitRead<'a, E>, E: Endianness> LazyBitRead<'a, T, E> {
     #[inline]
     /// Get the contents of the lazy struct
-    pub fn read(mut self) -> Result<T> {
-        self.source.read::<T>()
+    pub fn read(&self) -> Result<T> {
+        self.source.clone().read::<T>()
     }
 }
 
